summaryrefslogtreecommitdiffstats
path: root/src/dolphincontextmenu.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-27 00:40:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-27 00:40:29 +0000
commit7a741e43ff09e70396a918956219b8316c48e522 (patch)
tree3d0f60eccd59786cea7236db2d5c4c1f25874515 /src/dolphincontextmenu.h
parenta48487ef0c329434b58b6f920111bb0999f1109e (diff)
downloaddolphin-7a741e43ff09e70396a918956219b8316c48e522.tar.gz
dolphin-7a741e43ff09e70396a918956219b8316c48e522.zip
TQt4 port Dolphin
This enables compilation under Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/dolphin@1229359 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/dolphincontextmenu.h')
-rw-r--r--src/dolphincontextmenu.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/dolphincontextmenu.h b/src/dolphincontextmenu.h
index f14419e..1b0a0c9 100644
--- a/src/dolphincontextmenu.h
+++ b/src/dolphincontextmenu.h
@@ -22,18 +22,18 @@
#define DOLPHINCONTEXTMENU_H
#include <kpopupmenu.h>
-#include <qpoint.h>
-#include <qstring.h>
-#include <qvaluelist.h>
+#include <tqpoint.h>
+#include <tqstring.h>
+#include <tqvaluelist.h>
#include <kmountpoint.h>
-#include <qvaluevector.h>
+#include <tqvaluevector.h>
#include <kservice.h>
#include <kpropertiesdialog.h>
class KPopupMenu;
class KFileItem;
-class QPoint;
-class QWidget;
+class TQPoint;
+class TQWidget;
class DolphinView;
/**
@@ -54,16 +54,16 @@ class DolphinContextMenu
{
public:
/**
* @parent Pointer to the dolphin view the context menu
* belongs to.
* @fileInfo Pointer to the file item the context menu
* is applied. If 0 is passed, the context menu
* is above the viewport.
* @pos Position of the upper left edge of the context menu.
*/
- DolphinContextMenu(DolphinView* parent,
+ DolphinContextMenu(DolphinView* tqparent,
KFileItem* fileInfo,
- const QPoint& pos);
+ const TQPoint& pos);
virtual ~DolphinContextMenu();
@@ -85,7 +85,7 @@ private:
* to the predecessor.
*/
int insertOpenWithItems(KPopupMenu* popup,
- QValueVector<KService::Ptr>& openWithVector);
+ TQValueVector<KService::Ptr>& openWithVector);
/**
* Inserts the 'Actions...' submenu to \a popup.
@@ -95,14 +95,14 @@ private:
* services.
*/
void insertActionItems(KPopupMenu* popup,
- QValueVector<KDEDesktopMimeType::Service>& actionsVector);
+ TQValueVector<KDEDesktopMimeType::Service>& actionsVector);
/**
* Returns true, if 'menu' contains already
* an entry with the name 'entryName'.
*/
bool containsEntry(const KPopupMenu* menu,
- const QString& entryName) const;
+ const TQString& entryName) const;
enum {
restoreID = 80,
@@ -115,15 +115,15 @@ private:
DolphinView* m_dolphinView;
KFileItem* m_fileInfo;
- QPoint m_pos;
+ TQPoint m_pos;
struct Entry {
int type;
- QString name;
- QString filePath; // empty for separator
- QString templatePath; // same as filePath for template
- QString icon;
- QString comment;
+ TQString name;
+ TQString filePath; // empty for separator
+ TQString templatePath; // same as filePath for template
+ TQString icon;
+ TQString comment;
};
};
@@ -54,16 +54,16 @@ class DolphinContextMenu
public:
/**
- * @parent Pointer to the dolphin view the context menu
+ * @tqparent Pointer to the dolphin view the context menu
* belongs to.
* @fileInfo Pointer to the file item the context menu